@@ -14,7 +14,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.12.2.10 2003/03/23 06:46:34 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.18 2002/05/15 20:04:15 zacheiss Exp $");
 
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
@@ -114,7 +114,6 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
     KERNEL_SPACE_DECL;
     struct file *filp = &file->file;
     off_t offset = file->offset;
-    unsigned long savelim;
 
     /* Seek to the desired position. Return -1 on error. */
     if (filp->f_op->llseek) {
@@ -124,9 +123,6 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
     else
 	filp->f_pos = offset;
 
-    savelim = current->rlim[RLIMIT_FSIZE].rlim_cur;
-    current->rlim[RLIMIT_FSIZE].rlim_cur = RLIM_INFINITY;
-
     /* Read/Write the data. */
     TO_USER_SPACE();
     if (rw == UIO_READ)
@@ -137,8 +133,6 @@ int osi_rdwr(int rw, struct osi_file *file, caddr_t addrp, size_t asize,
 	code = asize;
     TO_KERNEL_SPACE();
 
-    current->rlim[RLIMIT_FSIZE].rlim_cur = savelim;
-
     if (code >=0) {
 	*resid = asize - code;
 	return 0;
@@ -158,10 +152,6 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
     int code = 0;
     struct iovec *iov;
     int count;
-    unsigned long savelim;
-
-    savelim = current->rlim[RLIMIT_FSIZE].rlim_cur;
-    current->rlim[RLIMIT_FSIZE].rlim_cur = RLIM_INFINITY;
 
     if (uiop->uio_seg == AFS_UIOSYS)
 	TO_USER_SPACE();
@@ -175,7 +165,7 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
 	    uiop->uio_iovcnt--;
 	    continue;
 	}
-
+	
 	if (rw == UIO_READ)
 	    code = FOP_READ(filp, iov->iov_base, count);
 	else
@@ -196,8 +186,6 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
     if (uiop->uio_seg == AFS_UIOSYS)
 	TO_KERNEL_SPACE();
 
-    current->rlim[RLIMIT_FSIZE].rlim_cur = savelim;
-
     return code;
 }
 
@@ -205,7 +193,7 @@ int osi_file_uio_rdwr(struct osi_file *osifile, uio_t *uiop, int rw)
  * Setup a uio struct.
  */
 void setup_uio(uio_t *uiop, struct iovec *iovecp, char *buf,
-			     int pos, int count, uio_flag_t flag,
+			     afs_offs_t pos, int count, uio_flag_t flag,
 			     uio_seg_t seg)
 {
     iovecp->iov_base = buf;
@@ -341,7 +329,7 @@ void osi_linux_free_inode_pages(void)
 void osi_clear_inode(struct inode *ip)
 {
     cred_t *credp = crref();
-    struct vcache *vcp = ITOAFS(ip);
+    struct vcache *vc = ITOAFS(ip);
 
 #if defined(AFS_LINUX24_ENV)
     if (atomic_read(&ip->i_count) > 1)
@@ -350,15 +338,15 @@ void osi_clear_inode(struct inode *ip)
 #endif
         printf("afs_put_inode: ino %d (0x%x) has count %d\n", ip->i_ino, ip);
 
-    afs_InactiveVCache(vcp, credp);
-    ObtainWriteLock(&vcp->lock, 504);
+    ObtainWriteLock(&vc->lock, 504);
+    afs_InactiveVCache(vc, credp);
+    ReleaseWriteLock(&vc->lock);
 #if defined(AFS_LINUX24_ENV)
     atomic_set(&ip->i_count, 0);
 #else
     ip->i_count = 0;
 #endif
     ip->i_nlink = 0; /* iput checks this after calling this routine. */
-    ReleaseWriteLock(&vcp->lock);
     crfree(credp);
 }
 
@@ -444,10 +432,18 @@ void check_bad_parent(struct dentry *dp)
 struct task_struct *rxk_ListenerTask;
 
 void osi_linux_mask() {
-    SIG_LOCK(current);
+    spin_lock_irq(&current->sigmask_lock);
     sigfillset(&current->blocked);
-    RECALC_SIGPENDING(current);
-    SIG_UNLOCK(current);
+    recalc_sigpending(current);
+    spin_unlock_irq(&current->sigmask_lock);
+}
+
+void osi_linux_unmask() {
+    spin_lock_irq(&rxk_ListenerTask->sigmask_lock);
+    sigemptyset(&rxk_ListenerTask->blocked);
+    flush_signals(rxk_ListenerTask);
+    recalc_sigpending(rxk_ListenerTask);
+    spin_unlock_irq(&rxk_ListenerTask->sigmask_lock);
 }
 
 void osi_linux_rxkreg() {
