@@ -22,7 +22,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_lookup.c,v 1.14.2.5 2002/07/22 23:14:54 zacheiss Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_lookup.c,v 1.30 2002/04/09 19:21:59 kolya Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -255,95 +255,7 @@ afs_InitFakeStat(state)
     state->valid = 1;
     state->did_eval = 0;
     state->need_release = 0;
-}
-
-/*
- * afs_EvalFakeStat_int
- *
- * The actual implementation of afs_EvalFakeStat and afs_TryEvalFakeStat,
- * which is called by those wrapper functions.
- *
- * Only issues RPCs if canblock is non-zero.
- */
-static int
-afs_EvalFakeStat_int(avcp, state, areq, canblock)
-    struct vcache **avcp;
-    struct afs_fakestat_state *state;
-    struct vrequest *areq;
-    int canblock;
-{
-    struct vcache *tvc, *root_vp;
-    struct volume *tvolp = NULL;
-    int code = 0;
-
-    osi_Assert(state->valid == 1);
-    osi_Assert(state->did_eval == 0);
-    state->did_eval = 1;
-    if (!afs_fakestat_enable)
-	return 0;
-    tvc = *avcp;
-    if (tvc->mvstat != 1)
-	return 0;
-
-    /* Is the call to VerifyVCache really necessary? */
-    code = afs_VerifyVCache(tvc, areq);
-    if (code)
-	goto done;
-    if (canblock) {
-	ObtainWriteLock(&tvc->lock, 599);
-	code = EvalMountPoint(tvc, NULL, &tvolp, areq);
-	ReleaseWriteLock(&tvc->lock);
-	if (code)
-	    goto done;
-	if (tvolp) {
-	    tvolp->dotdot = tvc->fid;
-	    tvolp->dotdot.Fid.Vnode = tvc->parentVnode;
-	    tvolp->dotdot.Fid.Unique = tvc->parentUnique;
-	}
-    }
-    if (tvc->mvid && (tvc->states & CMValid)) {
-	if (!canblock) {
-	    afs_int32 retry;
-
-	    do {
-		retry = 0;
-		ObtainWriteLock(&afs_xvcache, 597);
-		root_vp = afs_FindVCache(tvc->mvid, 0, 0, &retry, 0);
-		if (root_vp && retry) {
-		    ReleaseWriteLock(&afs_xvcache);
-		    afs_PutVCache(root_vp, 0);
-		}
-	    } while (root_vp && retry);
-	    ReleaseWriteLock(&afs_xvcache);
-	} else {
-	    root_vp = afs_GetVCache(tvc->mvid, areq, NULL, NULL, WRITE_LOCK);
-	}
-	if (!root_vp) {
-	    code = canblock ? ENOENT : 0;
-	    goto done;
-	}
-	if (tvolp) {
-	    /* Is this always kosher?  Perhaps we should instead use
-	     * NBObtainWriteLock to avoid potential deadlock.
-	     */
-	    ObtainWriteLock(&root_vp->lock, 598);
-	    if (!root_vp->mvid)
-		root_vp->mvid = osi_AllocSmallSpace(sizeof(struct VenusFid));
-	    *root_vp->mvid = tvolp->dotdot;
-	    ReleaseWriteLock(&root_vp->lock);
-	}
-	state->need_release = 1;
-	state->root_vp = root_vp;
-	*avcp = root_vp;
-	code = 0;
-    } else {
-	code = canblock ? ENOENT : 0;
-    }
-
-done:
-    if (tvolp)
-	afs_PutVolume(tvolp, WRITE_LOCK);
-    return code;
+    state->nonblock = 0;
 }
 
 /*
@@ -365,7 +277,78 @@ afs_EvalFakeStat(avcp, state, areq)
     struct afs_fakestat_state *state;
     struct vrequest *areq;
 {
-    return afs_EvalFakeStat_int(avcp, state, areq, 1);
+    struct vcache *tvc, *root_vp;
+    struct volume *tvolp = NULL;
+    int code = 0;
+
+    osi_Assert(state->valid == 1);
+    osi_Assert(state->did_eval == 0);
+    state->did_eval = 1;
+    if (!afs_fakestat_enable)
+	return 0;
+    tvc = *avcp;
+    if (tvc->mvstat != 1)
+	return 0;
+
+    /* Is the call to VerifyVCache really necessary? */
+    code = afs_VerifyVCache(tvc, areq);
+    if (code)
+	goto done;
+    if (!state->nonblock) {
+	ObtainWriteLock(&tvc->lock, 599);
+	code = EvalMountPoint(tvc, NULL, &tvolp, areq);
+	ReleaseWriteLock(&tvc->lock);
+	if (code)
+	    goto done;
+	if (tvolp) {
+	    tvolp->dotdot = tvc->fid;
+	    tvolp->dotdot.Fid.Vnode = tvc->parentVnode;
+	    tvolp->dotdot.Fid.Unique = tvc->parentUnique;
+	}
+    }
+    if (tvc->mvid && (tvc->states & CMValid)) {
+	if (state->nonblock) {
+	    afs_int32 retry;
+
+	    do {
+		retry = 0;
+		ObtainWriteLock(&afs_xvcache, 597);
+		root_vp = afs_FindVCache(tvc->mvid, 0, 0, &retry, 0);
+		if (root_vp && retry) {
+		    ReleaseWriteLock(&afs_xvcache);
+		    afs_PutVCache(root_vp, 0);
+		}
+	    } while (root_vp && retry);
+	    ReleaseWriteLock(&afs_xvcache);
+	} else {
+	    root_vp = afs_GetVCache(tvc->mvid, areq, NULL, NULL, WRITE_LOCK);
+	}
+	if (!root_vp) {
+	    code = state->nonblock ? 0 : ENOENT;
+	    goto done;
+	}
+	if (tvolp) {
+	    /* Is this always kosher?  Perhaps we should instead use
+	     * NBObtainWriteLock to avoid potential deadlock.
+	     */
+	    ObtainWriteLock(&root_vp->lock, 598);
+	    if (!root_vp->mvid)
+		root_vp->mvid = osi_AllocSmallSpace(sizeof(struct VenusFid));
+	    *root_vp->mvid = tvolp->dotdot;
+	    ReleaseWriteLock(&root_vp->lock);
+	}
+	state->need_release = 1;
+	state->root_vp = root_vp;
+	*avcp = root_vp;
+	code = 0;
+    } else {
+	code = state->nonblock ? 0 : ENOENT;
+    }
+
+done:
+    if (tvolp)
+	afs_PutVolume(tvolp, WRITE_LOCK);
+    return code;
 }
 
 /*
@@ -384,7 +367,8 @@ afs_TryEvalFakeStat(avcp, state, areq)
     struct afs_fakestat_state *state;
     struct vrequest *areq;
 {
-    return afs_EvalFakeStat_int(avcp, state, areq, 0);
+    state->nonblock = 1;
+    return afs_EvalFakeStat(avcp, state, areq);
 }
 
 /*
@@ -530,7 +514,7 @@ int afs_DoBulkStat(adp, dirCookie, areqp)
     struct dcache *dcp;		/* chunk containing the dir block */
     char *statMemp;		/* status memory block */
     char *cbfMemp;		/* callback and fid memory block */
-    long temp;			/* temp for holding chunk length, &c. */
+    afs_size_t temp;		/* temp for holding chunk length, &c. */
     struct AFSFid *fidsp;	/* file IDs were collecting */
     struct AFSCallBack *cbsp;	/* call back pointers */
     struct AFSCallBack *tcbp;	/* temp callback ptr */
@@ -551,7 +535,7 @@ int afs_DoBulkStat(adp, dirCookie, areqp)
     long startTime;		/* time we started the call,
 				 * for callback expiration base
 				 */
-    int statSeqNo;		/* Valued of file size to detect races */
+    afs_size_t statSeqNo;	/* Valued of file size to detect races */
     int code;			/* error code */
     long newIndex;		/* new index in the dir */
     struct DirEntry *dirEntryp;	/* dir entry we are examining */
@@ -603,7 +587,7 @@ tagain:
     code = afs_VerifyVCache(adp, areqp);
     if (code) goto done;
 
-    dcp = afs_GetDCache(adp, 0, areqp, &temp, &temp, 1);
+    dcp = afs_GetDCache(adp, (afs_size_t) 0, areqp, &temp, &temp, 1);
     if (!dcp) {
 	code = ENOENT;
 	goto done;
@@ -611,6 +595,7 @@ tagain:
 
     /* lock the directory cache entry */
     ObtainReadLock(&adp->lock);
+    ObtainReadLock(&dcp->lock);
 
     /*
      * Make sure that the data in the cache is current. There are two
@@ -619,15 +604,22 @@ tagain:
      * 2. The cache data is no longer valid
      */
     while ((adp->states & CStatd)
-	   && (dcp->flags & DFFetching)
+	   && (dcp->dflags & DFFetching)
 	   && hsame(adp->m.DataVersion, dcp->f.versionNo)) {
-	dcp->flags |= DFWaiting;
+	afs_Trace4(afs_iclSetp, CM_TRACE_DCACHEWAIT,
+			ICL_TYPE_STRING, __FILE__,
+			ICL_TYPE_INT32, __LINE__,
+			ICL_TYPE_POINTER, dcp,
+			ICL_TYPE_INT32, dcp->dflags);
+	ReleaseReadLock(&dcp->lock);
 	ReleaseReadLock(&adp->lock);
 	afs_osi_Sleep(&dcp->validPos);
 	ObtainReadLock(&adp->lock);
+	ObtainReadLock(&dcp->lock);
     }
     if (!(adp->states & CStatd)
 	|| !hsame(adp->m.DataVersion, dcp->f.versionNo)) {
+	ReleaseReadLock(&dcp->lock);
 	ReleaseReadLock(&adp->lock);
 	afs_PutDCache(dcp);
 	goto tagain;
@@ -683,7 +675,7 @@ tagain:
 	      tvcp = afs_FindVCache(&tfid, 0, 0, &retry, 0 /* no stats | LRU */);
 	      if (tvcp && retry) {
 		ReleaseWriteLock(&afs_xvcache);
-		afs_PutVCache(tvcp);
+		afs_PutVCache(tvcp, 0);
 	      }
 	    } while (tvcp && retry);
 	    if (!tvcp) {          /* otherwise, create manually */
@@ -734,7 +726,7 @@ tagain:
 		tvcp->m.Length = statSeqNo;
 		fidIndex++;
 	    }
-	    afs_PutVCache(tvcp);
+	    afs_PutVCache(tvcp, 0);
 	}	/* if dir vnode has non-zero entry */
 
 	/* move to the next dir entry by adding in the # of entries
@@ -747,6 +739,7 @@ tagain:
     }	/* while loop over all dir entries */
 
     /* now release the dir lock and prepare to make the bulk RPC */
+    ReleaseReadLock(&dcp->lock);
     ReleaseReadLock(&adp->lock);
 
     /* release the chunk */
@@ -774,20 +767,22 @@ tagain:
 #ifdef RX_ENABLE_LOCKS
 	    AFS_GUNLOCK();
 #endif /* RX_ENABLE_LOCKS */
-#ifdef notdef
-	    code = RXAFS_InlineBulkStatus(tcp->id, &fidParm, &statParm,
-					  &cbParm, &volSync);
-	    if (code == RXGEN_OPCODE) {
-#endif
+
+	    if (!(tcp->srvr->server->flags & SNO_INLINEBULK)) {
+		code = RXAFS_InlineBulkStatus(tcp->id, &fidParm, &statParm,
+					      &cbParm, &volSync);
+		if (code == RXGEN_OPCODE) {
+		    tcp->srvr->server->flags |= SNO_INLINEBULK;
+		    inlinebulk = 0;
+		    code = RXAFS_BulkStatus(tcp->id, &fidParm, &statParm, 
+					    &cbParm, &volSync);
+		} else
+		    inlinebulk=1;
+	    } else {
+		inlinebulk=0;
 		code = RXAFS_BulkStatus(tcp->id, &fidParm, &statParm, &cbParm,
 					&volSync);
-		inlinebulk=0;
-#ifdef notdef
-	    } else {
-		inlinebulk=1;
 	    }
-#endif
-
 #ifdef RX_ENABLE_LOCKS
 	    AFS_GLOCK();
 #endif /* RX_ENABLE_LOCKS */
@@ -889,7 +884,7 @@ tagain:
 	if (!(tvcp->states & CBulkFetching) || (tvcp->m.Length != statSeqNo)) {
 	    flagIndex++;
 	    ReleaseWriteLock(&tvcp->lock);
-	    afs_PutVCache(tvcp);
+	    afs_PutVCache(tvcp, 0);
 	    continue;
 	}
 
@@ -936,7 +931,7 @@ tagain:
 	    flagIndex++;
 	    ReleaseWriteLock(&tvcp->lock);
 	    ReleaseWriteLock(&afs_xcbhash);
-	    afs_PutVCache(tvcp);
+	    afs_PutVCache(tvcp, 0);
 	    continue;
 	}
 
@@ -996,11 +991,11 @@ tagain:
 
 	ReleaseWriteLock(&tvcp->lock);
 	/* finally, we're done with the entry */
-	afs_PutVCache(tvcp);
+	afs_PutVCache(tvcp, 0);
     }	/* for all files we got back */
 
     /* finally return the pointer into the LRU queue */
-    afs_PutVCache(lruvcp);
+    afs_PutVCache(lruvcp, 0);
 
   done:
     /* Be sure to turn off the CBulkFetching flags */
@@ -1021,7 +1016,7 @@ tagain:
 	  tvcp->states &= ~CBulkFetching;
 	}
 	if (tvcp != NULL) {
-	  afs_PutVCache(tvcp);
+	  afs_PutVCache(tvcp, 0);
 	}
     }
     if ( volp )
@@ -1230,12 +1225,12 @@ afs_lookup(adp, aname, avcp, acred)
 
     {
     register struct dcache *tdc;
-    afs_int32 dirOffset, dirLen;
+    afs_size_t dirOffset, dirLen;
     ino_t theDir;
     struct VenusFid tfid;
 
     /* now we have to lookup the next fid */
-    tdc = afs_GetDCache(adp, 0, &treq, &dirOffset, &dirLen, 1);
+    tdc = afs_GetDCache(adp, (afs_size_t) 0, &treq, &dirOffset, &dirLen, 1);
     if (!tdc) {
       *avcp = (struct vcache *)0;  /* redundant, but harmless */
       code = EIO;
@@ -1245,6 +1240,7 @@ afs_lookup(adp, aname, avcp, acred)
     /* now we will just call dir package with appropriate inode.
       Dirs are always fetched in their entirety for now */
     ObtainReadLock(&adp->lock);
+    ObtainReadLock(&tdc->lock);
 
     /*
      * Make sure that the data in the cache is current. There are two
@@ -1253,15 +1249,17 @@ afs_lookup(adp, aname, avcp, acred)
      * 2. The cache data is no longer valid
      */
     while ((adp->states & CStatd)
-	   && (tdc->flags & DFFetching)
+	   && (tdc->dflags & DFFetching)
 	   && hsame(adp->m.DataVersion, tdc->f.versionNo)) {
-	tdc->flags |= DFWaiting;
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&adp->lock);
 	afs_osi_Sleep(&tdc->validPos);
 	ObtainReadLock(&adp->lock);
+	ObtainReadLock(&tdc->lock);
     }
     if (!(adp->states & CStatd)
 	|| !hsame(adp->m.DataVersion, tdc->f.versionNo)) {
+	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&adp->lock);
 	afs_PutDCache(tdc);
 	goto redo;
@@ -1292,6 +1290,7 @@ afs_lookup(adp, aname, avcp, acred)
     }
     tname = sysState.name;
 
+    ReleaseReadLock(&tdc->lock);
     afs_PutDCache(tdc);
 
     if (code == ENOENT && afs_IsDynroot(adp) && dynrootRetry) {
@@ -1349,7 +1348,7 @@ afs_lookup(adp, aname, avcp, acred)
 
 	/* if the vcache isn't usable, release it */
 	if (tvc && !(tvc->states & CStatd)) {
-	    afs_PutVCache(tvc);
+	    afs_PutVCache(tvc, 0);
 	    tvc = (struct vcache *) 0;
 	}
     } else {
