@@ -32,26 +32,21 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_server.c,v 1.11.2.7 2003/05/20 04:23:07 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_server.c,v 1.17 2002/03/21 18:11:50 shadow Exp $");
 
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 
 #if !defined(UKERNEL)
-#if !defined(AFS_LINUX20_ENV)
 #include <net/if.h>
-#endif
 #include <netinet/in.h>
 
 #ifdef AFS_SGI62_ENV
 #include "../h/hashing.h"
 #endif
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN60_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX20_ENV)
 #include <netinet/in_var.h>
 #endif /* AFS_HPUX110_ENV */
-#ifdef AFS_DARWIN60_ENV
-#include <net/if_var.h>
-#endif
 #endif /* !defined(UKERNEL) */
 
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -92,26 +87,6 @@ int afs_totalSrvAddrs = 0;
 
 
 
-static struct afs_stats_SrvUpDownInfo *
-GetUpDownStats(struct server *srv)
-{
-    struct afs_stats_SrvUpDownInfo *upDownP;
-    u_short fsport = AFS_FSPORT;
-
-    if (srv->cell)
-	fsport = srv->cell->fsport;
-
-    if (srv->addr->sa_portal == fsport)
-	upDownP = afs_stats_cmperf.fs_UpDown;
-    else
-	upDownP = afs_stats_cmperf.vl_UpDown;
-
-    if (srv->cell && afs_IsPrimaryCell(srv->cell))
-	return &upDownP[AFS_STATS_UPDOWN_IDX_SAME_CELL];
-    else
-	return &upDownP[AFS_STATS_UPDOWN_IDX_DIFF_CELL];
-}
-
 
 /*------------------------------------------------------------------------
  * afs_MarkServerUpOrDown
@@ -187,7 +162,16 @@ void afs_MarkServerUpOrDown(struct srvAddr *sa, int a_isDown)
     currTimeP = &currTime;
     osi_GetuTime(currTimeP);
 
-    upDownP = GetUpDownStats(a_serverP);
+    if (sa->sa_portal == AFS_FSPORT) {
+	upDownP = (a_serverP->cell->cell == 1) ?
+	    &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+	    &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+    } /*File Server record*/
+    else {
+	upDownP = (a_serverP->cell->cell == 1) ?
+	    &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+	    &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+    } /*VL Server record*/
 
     if (a_isDown) {
 	/*
@@ -308,18 +292,14 @@ static void CheckVLServer(sa, areq)
 	return;	/* can't do much */
 
     tc = afs_ConnByHost(aserver, aserver->cell->vlport, 
-			aserver->cell->cellNum, areq, 1, SHARED_LOCK);
+			aserver->cell->cell, areq, 1, SHARED_LOCK);
     if (!tc)
 	return;
     rx_SetConnDeadTime(tc->id, 3);
 
-#ifdef RX_ENABLE_LOCKS
-    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GUNLOCK();
     code = VL_ProbeServer(tc->id);
-#ifdef RX_ENABLE_LOCKS
-    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+    RX_AFS_GLOCK();
     rx_SetConnDeadTime(tc->id, AFS_RXDEADTIME);
     afs_PutConn(tc, SHARED_LOCK);
     /*
@@ -442,7 +422,17 @@ void afs_CountServers()
 		 * in the appropriate places.
 		 */
 		srvRecordAge = currTime.tv_sec - currSrvP->activationTime;
-		upDownP = GetUpDownStats(currSrvP);
+		if (currSrvP->addr->sa_portal == AFS_FSPORT) {
+		    upDownP = (currSrvP->cell->cell == 1) ?
+			&(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]):
+			&(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+		} /*File Server record*/
+		else {
+		    upDownP = (currSrvP->cell->cell == 1) ?
+			&(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]):
+			&(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+		} /*VL Server record*/
+
 		upDownP->sumOfRecordAges += srvRecordAge;
 		if ((upDownP->ageOfYoungestRecord == 0) ||
 		    (srvRecordAge < upDownP->ageOfYoungestRecord))
@@ -571,8 +561,8 @@ void afs_CheckServers(adown, acellp)
 	    continue;  /* have just been added by setsprefs */ 
 
 	/* get a connection, even if host is down; bumps conn ref count */
-	tu = afs_GetUser(treq.uid, ts->cell->cellNum, SHARED_LOCK);
-	tc = afs_ConnBySA(sa, ts->cell->fsport, ts->cell->cellNum, tu,
+	tu = afs_GetUser(treq.uid, ts->cell->cell, SHARED_LOCK);
+	tc = afs_ConnBySA(sa, ts->cell->fsport, ts->cell->cell, tu,
 			  1/*force*/, 1/*create*/, SHARED_LOCK);
 	afs_PutUser(tu, SHARED_LOCK);
 	if (!tc) continue;
@@ -588,13 +578,9 @@ void afs_CheckServers(adown, acellp)
 
 	    XSTATS_START_TIME(AFS_STATS_FS_RPCIDX_GETTIME);
 	    start = osi_Time();		/* time the gettimeofday call */
-#ifdef RX_ENABLE_LOCKS
-	    AFS_GUNLOCK();
-#endif /* RX_ENABLE_LOCKS */
+	    RX_AFS_GUNLOCK();
 	    code = RXAFS_GetTime(tc->id, &tv.tv_sec, &tv.tv_usec);
-#ifdef RX_ENABLE_LOCKS
-	    AFS_GLOCK();
-#endif /* RX_ENABLE_LOCKS */
+	    RX_AFS_GLOCK();
 	    end = osi_Time();
 	    XSTATS_END_TIME;
 	    /*
@@ -605,9 +591,12 @@ void afs_CheckServers(adown, acellp)
 	     */
 	    if (code == 0 && start == end && afs_setTime != 0 &&
 		(tc->srvr->server == afs_setTimeHost ||
-		/* Sync only to a server in the local cell */
+		/*
+		 * Sync only to a server in the local cell: cell(id)==1
+		 * or CPrimary.
+		 */
 		(afs_setTimeHost == (struct server *)0 &&
-		 afs_IsPrimaryCell(ts->cell)))) {
+		 (ts->cell->cell == 1 || (ts->cell->states&CPrimary))))) {
 
 		char msgbuf[90];  /* strlen("afs: setting clock...") + slop */
 		/* set the time */
@@ -1042,7 +1031,7 @@ afsi_SetServerIPRank(sa, addr, subnetmask)
    }
 }
 #else /* AFS_USERSPACE_IP_ADDR */
-#if (! defined(AFS_SUN5_ENV)) && !defined(AFS_DARWIN60_ENV) && defined(USEIFADDR)
+#if (! defined(AFS_SUN5_ENV)) && defined(USEIFADDR)
 void
 afsi_SetServerIPRank(sa, ifa)
     struct srvAddr *sa;
@@ -1081,65 +1070,6 @@ afsi_SetServerIPRank(sa, ifa)
 #endif /* IFF_POINTTOPOINT */
 }
 #endif /*(!defined(AFS_SUN5_ENV)) && defined(USEIFADDR)*/
-#if defined(AFS_DARWIN60_ENV) && defined(USEIFADDR)
-#ifndef afs_min
-#define afs_min(A,B) ((A)<(B)) ? (A) : (B)
-#endif
-void
-afsi_SetServerIPRank(sa, ifa)
-    struct srvAddr *sa;
-    struct ifaddr *ifa;
-{
-    struct sockaddr_in *sin;
-    int t;
-    
-   afs_uint32 subnetmask, myAddr, myNet, myDstaddr, mySubnet, netMask;
-   afs_uint32 serverAddr ; 
-
-   if (ifa->ifa_addr->sa_family != AF_INET)
-      return;
-   sin=(struct sockaddr_in *)ifa->ifa_addr;
-   myAddr = ntohl(sin->sin_addr.s_addr);   /* one of my IP addr in host order */
-   serverAddr = ntohl(sa->sa_ip); /* server's IP addr in host order */
-   sin=(struct sockaddr_in *)ifa->ifa_netmask;
-   subnetmask = ntohl(sin->sin_addr.s_addr);/* subnet mask in host order */
-   sin=(struct sockaddr_in *)ifa->ifa_dstaddr;
-   if (sin)
-      myDstaddr=sin->sin_addr.s_addr;
-
-   if      ( IN_CLASSA(myAddr) ) netMask = IN_CLASSA_NET;
-   else if ( IN_CLASSB(myAddr) ) netMask = IN_CLASSB_NET;
-   else if ( IN_CLASSC(myAddr) ) netMask = IN_CLASSC_NET;
-   else                          netMask = 0;
-
-   myNet    =  myAddr & netMask;
-   mySubnet =  myAddr & subnetmask;
-
-   if ( (serverAddr & netMask ) == myNet ) {
-      if ( (serverAddr & subnetmask ) == mySubnet) {
-	 if ( serverAddr == myAddr ) {    /* same machine */
-	   sa->sa_iprank = afs_min(sa->sa_iprank, TOPR);
-	 } else {                           /* same subnet */
-	    sa->sa_iprank = afs_min(sa->sa_iprank, HI + ifa->ifa_metric);
-	 }
-      } else {                               /* same net */
-	 sa->sa_iprank = afs_min(sa->sa_iprank, MED + ifa->ifa_metric);
-      }
-   }
-#ifdef  IFF_POINTTOPOINT
-    /* check for case #4 -- point-to-point link */
-    if ((ifa->ia_ifp->if_flags & IFF_POINTOPOINT) &&
-	(myDstaddr == serverAddr))) {
-	if (ifa->ia_ifp->if_metric >= (MAXDEFRANK - MED)/PPWEIGHT) 
-	    t = MAXDEFRANK;
-	else 
-	    t = MED + (PPWEIGHT << ifa->->ifa_metric);
-	if (sa->sa_iprank > t)
-	    sa->sa_iprank = t;
-    }
-#endif /* IFF_POINTTOPOINT */
-}
-#endif /*(!defined(AFS_SUN5_ENV)) && defined(USEIFADDR)*/
 #endif /* else AFS_USERSPACE_IP_ADDR */
 
 #ifdef AFS_SGI62_ENV
@@ -1297,16 +1227,6 @@ static afs_SetServerPrefs(sa)
 #ifdef AFS_SGI62_ENV
     (void) hash_enum(&hashinfo_inaddr, afsi_enum_set_rank, HTF_INET, NULL,
 		     (caddr_t)sa, NULL);
-#elif defined(AFS_DARWIN60_ENV)
-    {
-        struct ifnet *ifn;
-        struct ifaddr *ifa;
-        TAILQ_FOREACH(ifn , &ifnet, if_link) {
-            TAILQ_FOREACH(ifa , &ifn->if_addrhead, ifa_link) {
-                afsi_SetServerIPRank(sa, ifa);
-            }
-        }
-    }
 #elif defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
     {
         struct in_ifaddr *ifa;
@@ -1605,8 +1525,16 @@ struct server *afs_GetServer(afs_uint32 *aserverp, afs_int32 nservers,
        /* With the introduction of this new record, we need to adjust the
 	* proper individual & global server up/down info.
 	*/
-       upDownP = GetUpDownStats(newts);
-       upDownP->numTtlRecords      += srvcount;
+       if (aport == fsport) {   /* File Server record */
+	  upDownP = (acell == 1) ?
+	    &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+	    &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+       } else {                   /* VL Server record */
+	  upDownP = (acell == 1) ?
+	    &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+	    &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+       } 
+       (upDownP->numTtlRecords)    += srvcount;
        afs_stats_cmperf.srvRecords += srvcount;
        if (afs_stats_cmperf.srvRecords > afs_stats_cmperf.srvRecordsHWM)
 	  afs_stats_cmperf.srvRecordsHWM = afs_stats_cmperf.srvRecords;
@@ -1634,12 +1562,21 @@ void afs_ActivateServer(sap)
       currTimeP = &currTime;
       osi_GetuTime(currTimeP);
       aserver->activationTime = currTime.tv_sec;
-      upDownP = GetUpDownStats(aserver);
-      if (aserver->flags & SRVR_ISDOWN) {
-	 upDownP->numDownRecords++;
-      } else {
-	 upDownP->numUpRecords++;
-	 upDownP->numRecordsNeverDown++;
+      if (sap->sa_portal == AFS_FSPORT) {
+	 upDownP = (aserver->cell->cell == 1) ?
+	      &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+		   &(afs_stats_cmperf.fs_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+      } /*File Server record*/
+      else {
+	 upDownP = (aserver->cell->cell == 1) ?
+	      &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_SAME_CELL]) :
+		   &(afs_stats_cmperf.vl_UpDown[AFS_STATS_UPDOWN_IDX_DIFF_CELL]);
+      } /*VL Server record*/
+      if (aserver->flags & SRVR_ISDOWN)
+	   (upDownP->numDownRecords)++;
+      else {
+	 (upDownP->numUpRecords)++;
+	 (upDownP->numRecordsNeverDown)++;
       }
    }
 }
