@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/butm/file_tm.c,v 1.5.2.1 2003/07/29 22:36:10 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/butm/file_tm.c,v 1.5 2001/08/08 00:03:40 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -30,15 +30,6 @@ RCSID("$Header: /cvs/openafs/src/butm/file_tm.c,v 1.5.2.1 2003/07/29 22:36:10 sh
 #include <afs/usd.h>
 #include "error_macros.h"
 
-#ifdef O_LARGEFILE
-typedef off64_t         osi_lloff_t;
-#else /* O_LARGEFILE */
-#ifdef AFS_HAVE_LLSEEK
-typedef offset_t        osi_lloff_t;
-#else /* AFS_HAVE_LLSEEK */
-typedef off_t           osi_lloff_t;
-#endif /* AFS_HAVE_LLSEEK */
-#endif /* O_LARGEFILE */
  
 extern int isafile;
 
@@ -84,6 +75,7 @@ extern int isafile;
  * in succession (2 or 4 of them ).
  */
 
+
 struct fileMark {			/* in network byte order */
     afs_int32 magic;
     afs_uint32 nBytes;
@@ -678,7 +670,7 @@ incPosition(info, fid, dataSize)
    if ( info->posCount >=  2147467264 )                 /* 2GB - 16K */
    {
       info->posCount = 0;
-#if (defined(AFS_SUN_ENV) || defined(AFS_DEC_ENV) || defined(AFS_LINUX24_ENV))
+#if (defined(AFS_SUN_ENV) || defined(AFS_DEC_ENV))
       if (!isafile)
 	{
 	  hset64(off, 0, 0);
@@ -1582,9 +1574,7 @@ static afs_int32 file_Seek (info, position)
     afs_int32 position;
 {   
     afs_int32 code = 0;
-    afs_int32 w;
-    osi_lloff_t posit;
-    afs_uint32 c, d;
+    afs_int32 posit, w;
     struct progress *p;
     afs_hyper_t startOff, stopOff;  /* for normal file(non-tape)  seeks  */
 
@@ -1598,17 +1588,9 @@ static afs_int32 file_Seek (info, position)
     if (isafile)
     {
 	p = (struct progress *)info->tmRock;
-        posit = (osi_lloff_t)position * (osi_lloff_t)BUTM_BLOCKSIZE;
-	/* Not really necessary to do it this way, should be fixed. */
-#ifdef O_LARGEFILE
-	c = (posit >> 32);
-	d = (posit & 0xffffffff);
-#else
-	c = 0;
-	d = posit;
-#endif
-	hset64(startOff, c, d);
-
+        posit = (position * BUTM_BLOCKSIZE);
+	
+	hset64(startOff, 0, posit);
 	w = USD_SEEK(p->fid, startOff, SEEK_SET, &stopOff);
 	if (w) info->error == w;
 	if (hcmp(startOff, stopOff) != 0) ERROR_EXIT(BUTM_POSITION);
