@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/klog.c,v 1.5 2001/08/08 00:03:46 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/klog.c,v 1.6 2001/10/05 21:17:18 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -18,6 +18,13 @@ RCSID("$Header: /cvs/openafs/src/kauth/klog.c,v 1.5 2001/08/08 00:03:46 shadow E
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 
 #include <lock.h>
 #include <ubik.h>
