@@ -18,7 +18,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /cvs/openafs/src/kauth/token.c,v 1.4.4.1 2001/09/19 22:36:23 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/token.c,v 1.6 2001/10/05 21:17:18 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "../afs/sysincludes.h"
@@ -43,6 +43,13 @@ RCSID("$Header: /cvs/openafs/src/kauth/token.c,v 1.4.4.1 2001/09/19 22:36:23 sha
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 /* netinet/in.h and cellconfig.h  are needed together */
 #include <afs/cellconfig.h>
     /* these are needed together */
