@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/ptserver/utils.c,v 1.7 2001/08/08 00:03:54 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/ptserver/utils.c,v 1.9 2001/10/05 21:07:17 shadow Exp $");
 
 #include <sys/types.h>
 #include <lock.h>
@@ -22,6 +22,13 @@ RCSID("$Header: /cvs/openafs/src/ptserver/utils.c,v 1.7 2001/08/08 00:03:54 shad
 #include <netinet/in.h>
 #include <netdb.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include "ptserver.h"
 #include "pterror.h"
 
@@ -402,7 +409,6 @@ register struct ubik_trans *at;
 char aname[PR_MAXNAMELEN];
 afs_int32 *aid;
 {
-    register afs_int32 code;
     afs_int32 temp;
     struct prentry tentry;
 
