@@ -16,11 +16,7 @@
 #include <afs/param.h>
 #endif
 
-#ifdef AFS_SUN59_ENV
-#include <sys/time_impl.h>
-#endif
-
-RCSID("$Header: /cvs/openafs/src/rxkad/rxkad_common.c,v 1.8.2.4 2002/07/10 19:43:20 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/rxkad/rxkad_common.c,v 1.10 2002/04/25 21:18:23 shadow Exp $");
 
 #ifdef KERNEL
 #ifndef UKERNEL
@@ -33,7 +29,7 @@ RCSID("$Header: /cvs/openafs/src/rxkad/rxkad_common.c,v 1.8.2.4 2002/07/10 19:43
 #include "../h/time.h"
 #ifndef AFS_LINUX22_ENV
 #include "../rpc/types.h"
-#include "../rx/xdr.h"
+#include "../rpc/xdr.h"
 #endif /* AFS_LINUX22_ENV */
 #else /* !UKERNEL */
 #include "../afs/sysincludes.h"
