@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/venus/fs.c,v 1.12.2.6 2003/07/02 00:44:37 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/venus/fs.c,v 1.14 2002/03/10 19:08:03 shadow Exp $");
 
 #include <afs/afs_args.h>
 #include <rx/xdr.h>
@@ -43,13 +43,6 @@ RCSID("$Header: /cvs/openafs/src/venus/fs.c,v 1.12.2.6 2003/07/02 00:44:37 shado
 #include <strings.h>
 #include <afs/afsutil.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <assert.h>
 #include <afs/ptclient.h>
 
@@ -71,9 +64,8 @@ static int RxStatProcCmd(), RxStatPeerCmd();
 
 extern char *hostutil_GetNameByINet();
 extern struct hostent *hostutil_GetHostByName();
-extern afs_int32 VL_GetEntryByNameO();
-
 
+extern int errno;
 extern struct cmd_syndesc *cmd_CreateSyntax();
 static char pn[] = "fs";
 static int rxInitDone = 0;
@@ -1916,8 +1908,6 @@ static NewCellCmd(as)
      * MAXCELLHOSTS (8) servers. To determine which we are talking to,
      * do a GETCELL pioctl and pass it a magic number. If an array of
      * 8 comes back, its a 3.5 client. If not, its a 3.4 client.
-     * If we get back EDOM, there are no cells in the kernel yet,
-     * and we'll assume a 3.5 client.
      */
     tp = space;
     lp = (afs_int32 *)tp;
@@ -1928,17 +1918,13 @@ static NewCellCmd(as)
     blob.in       = space;
     blob.out      = space;
     code = pioctl(0, VIOCGETCELL, &blob, 1);
-    if (code < 0 && errno != EDOM) {
+    if (code < 0) {
        Die(errno, 0);
        return 1;
     }
-    if (code < 1 && errno == EDOM) {
-       scount = MAXHOSTS;
-    } else {
-       tp = space;
-       cellname = tp + MAXCELLHOSTS*sizeof(afs_int32);
-       scount = ((cellname[0] != '\0') ? MAXCELLHOSTS : MAXHOSTS);
-    }
+    tp = space;
+    cellname = tp + MAXCELLHOSTS*sizeof(afs_int32);
+    scount = ((cellname[0] != '\0') ? MAXCELLHOSTS : MAXHOSTS);
 
     /* Now setup and do the NEWCELL pioctl call */
     memset(space, 0, (scount+1) * sizeof(afs_int32));
