@@ -82,7 +82,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/viced/callback.c,v 1.6.2.9 2003/05/15 15:51:59 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/viced/callback.c,v 1.10 2002/02/01 22:12:51 shadow Exp $");
 
 #include <stdio.h> 
 #include <stdlib.h>      /* for malloc() */
@@ -442,7 +442,7 @@ static CDel(cb)
 	assert(0);
 	ViceLog(0,("CDel: Internal Error -- shutting down: wanted %d from %d, now at %d\n",cbi,fe->firstcb,*cbp));
 	DumpCallBackState();
-	ShutDownAndCore(PANIC);
+	ShutDown();
       }
     }
     CDelPtr(fe, cbp);
@@ -492,7 +492,7 @@ static u_short *FindCBPtr(fe, host)
 	if (safety > cbstuff.nblks) {
 	  ViceLog(0,("FindCBPtr: Internal Error -- shutting down.\n"));
 	  DumpCallBackState();
-	  ShutDownAndCore(PANIC);
+	  ShutDown();
 	}
 	cb = itocb(*cbp);
 	if (cb->hhead == hostindex)
@@ -695,7 +695,7 @@ AddCallBack1_r(host, fid, thead, type, locked)
 	if (safety > cbstuff.nblks) {
 	  ViceLog(0,("AddCallBack1: Internal Error -- shutting down.\n"));
 	  DumpCallBackState();
-	  ShutDownAndCore(PANIC);
+	  ShutDown();
 	}
 	if (cb->hhead == h_htoi(host))
 	    break;
@@ -788,6 +788,8 @@ static void MultiBreakCallBack_r(cba, ncbas, afidp, xhost)
     if (multi_error) {
       unsigned short idx ;
       struct host *hp;
+      char hoststr[16];
+
       idx = 0;
       /* If there's an error, we have to hunt for the right host. 
        * The conns array _should_ correspond one-to-one to the cba
@@ -817,9 +819,9 @@ static void MultiBreakCallBack_r(cba, ncbas, afidp, xhost)
 	{
 	  if (ShowProblems) {
 	  	ViceLog(7, 
-		  ("BCB: Failed on file %u.%d.%d, host %x.%d is down\n",
+		  ("BCB: Failed on file %u.%d.%d, host %s:%d is down\n",
 		   afidp->AFSCBFids_val->Volume, afidp->AFSCBFids_val->Vnode,
-		   afidp->AFSCBFids_val->Unique, hp->host, ntohs(hp->port)));
+		   afidp->AFSCBFids_val->Unique, afs_inet_ntoa_r(hp->host,hoststr), hp->port));
 		}
 
 		H_LOCK
@@ -870,9 +872,10 @@ BreakCallBack(xhost, fid, flag)
     struct rx_connection *conns[MAX_CB_HOSTS];
     struct AFSCBFids tf;
     int hostindex;
+    char hoststr[16];
 
-    ViceLog(7,("BCB: BreakCallBack(all but %x.%d, (%u,%d,%d))\n",
-	       xhost->host, ntohs(xhost->port), fid->Volume, fid->Vnode, 
+    ViceLog(7,("BCB: BreakCallBack(all but %s:%d, (%u,%d,%d))\n",
+	       afs_inet_ntoa_r(xhost->host,hoststr), xhost->port, fid->Volume, fid->Vnode, 
 	       fid->Unique));
 
     H_LOCK
@@ -902,8 +905,8 @@ BreakCallBack(xhost, fid, flag)
 	    ViceLog(0,("BCB: BOGUS! cb->hhead is NULL!\n"));
 	  }
 	  else if (thishost->hostFlags & VENUSDOWN) {
-	    ViceLog(7,("BCB: %x.%d is down; delaying break call back\n",
-		       thishost->host, ntohs(thishost->port)));
+	    ViceLog(7,("BCB: %s:%d is down; delaying break call back\n",
+		       afs_inet_ntoa_r(thishost->host,hoststr), thishost->port));
 	    cb->status = CB_DELAYED;
 	  }
 	  else {
@@ -949,6 +952,8 @@ DeleteCallBack(host, fid)
 {
     register struct FileEntry *fe;
     register u_short *pcb;
+    char hoststr[16];
+
     cbstuff.DeleteCallBacks++;
     
     H_LOCK
@@ -963,8 +968,8 @@ DeleteCallBack(host, fid)
     }
     pcb = FindCBPtr(fe, host);
     if (!*pcb) {
-	ViceLog(8,("DCB: No call back for host %x.%d, (%u, %d, %d)\n",
-	    host->host, ntohs(host->port), fid->Volume, fid->Vnode, fid->Unique));
+	ViceLog(8,("DCB: No call back for host %s:%d, (%u, %d, %d)\n",
+	    afs_inet_ntoa_r(host->host,hoststr), host->port, fid->Volume, fid->Vnode, fid->Unique));
 	h_Unlock_r(host);
 	H_UNLOCK
 	return;
@@ -1075,6 +1080,7 @@ int BreakDelayedCallBacks_r(host)
     struct CallBack *cb;
     struct interfaceAddr interf;
     int code;
+    char hoststr[16];
 
     cbstuff.nbreakers++;
     if (!(host->hostFlags & RESETDONE) && !(host->hostFlags & HOSTDELETED)) {
@@ -1093,13 +1099,13 @@ int BreakDelayedCallBacks_r(host)
 	if (code) {
 	    if (ShowProblems) {
 		ViceLog(0,
-	   ("CB: Call back connect back failed (in break delayed) for %x.%d\n",
-			host->host, ntohs(host->port)));
+	   ("CB: Call back connect back failed (in break delayed) for %s:%d\n",
+			afs_inet_ntoa_r(host->host,hoststr), host->port));
 	      }
 	    host->hostFlags |= VENUSDOWN;
 	}
 	else {
-	    ViceLog(25,("InitCallBackState success on %x\n",host->host));
+	    ViceLog(25,("InitCallBackState success on %s\n",afs_inet_ntoa_r(host->host,hoststr)));
 	    /* reset was done successfully */
 	    host->hostFlags |= RESETDONE;
 	    host->hostFlags &= ~VENUSDOWN;
@@ -1138,14 +1144,14 @@ int BreakDelayedCallBacks_r(host)
 	    int i;
 	    if (ShowProblems) {
 		ViceLog(0,
-	     ("CB: XCallBackBulk failed, host=%x.%d; callback list follows:\n",
-		    host->host, ntohs(host->port)));
+	     ("CB: XCallBackBulk failed, host=%s:%d; callback list follows:\n",
+		    afs_inet_ntoa_r(host->host,hoststr), host->port));
 	    }
 	    for (i = 0; i<nfids; i++) {
 		if (ShowProblems) {
 		    ViceLog(0,
-		    ("CB: Host %x.%d, file %u.%u.%u (part of bulk callback)\n",
-		               host->host, ntohs(host->port), 
+		    ("CB: Host %s:%d, file %u.%u.%u (part of bulk callback)\n",
+		               afs_inet_ntoa_r(host->host,hoststr), host->port, 
 		               fids[i].Volume, fids[i].Vnode, fids[i].Unique));
 		}
 		/* used to do this:
@@ -1184,6 +1190,8 @@ static int MultiBreakVolumeCallBack_r (host, isheld, parms)
   int isheld;
   struct VCBParams *parms;
 {
+    char hoststr[16];
+
     if ( !isheld )
 	return isheld; /* host is held only by h_Enumerate, do nothing */
     if ( host->hostFlags & HOSTDELETED )
@@ -1195,11 +1203,11 @@ static int MultiBreakVolumeCallBack_r (host, isheld, parms)
 	    h_Unlock_r(host);
 	    return 0;      /* Release hold */
 	}
-	ViceLog(8,("BVCB: volume call back for host %x.%d failed\n",
-		 host->host,ntohs(host->port)));
+	ViceLog(8,("BVCB: volume call back for host %s:%d failed\n",
+		 afs_inet_ntoa_r(host->host,hoststr),host->port));
 	if (ShowProblems) {
-	    ViceLog(0, ("CB: volume callback for host %x.%d failed\n",
-		    host->host, ntohs(host->port)));
+	    ViceLog(0, ("CB: volume callback for host %s:%d failed\n",
+		    afs_inet_ntoa_r(host->host,hoststr), host->port));
 	}
 	DeleteAllCallBacks_r(host); /* Delete all callback state rather than
 				     attempting to selectively remember to
@@ -1342,6 +1350,8 @@ CleanupTimedOutCallBacks_r()
     register u_short *thead;
     register struct CallBack *cb;
     register int ntimedout = 0;
+    char hoststr[16];
+
     extern void ShutDown();
 
     while (tfirst <= now) {
@@ -1351,8 +1361,8 @@ CleanupTimedOutCallBacks_r()
 	    do {
 		cb = itocb(cbi);
 		cbi = cb->tnext;
-		ViceLog(8,("CCB: deleting timed out call back %x.%d, (%u,%u,%u)\n",
-			h_itoh(cb->hhead)->host, h_itoh(cb->hhead)->port, 
+		ViceLog(8,("CCB: deleting timed out call back %s:%d, (%u,%u,%u)\n",
+			afs_inet_ntoa_r(h_itoh(cb->hhead)->host, hoststr), h_itoh(cb->hhead)->port, 
 			itofe(cb->fhead)->volid, itofe(cb->fhead)->vnode,
 			itofe(cb->fhead)->unique));
 		HDel(cb);
@@ -1361,7 +1371,7 @@ CleanupTimedOutCallBacks_r()
 		if (ntimedout > cbstuff.nblks) {
 		  ViceLog(0,("CCB: Internal Error -- shutting down...\n"));
 		  DumpCallBackState();
-		  ShutDownAndCore(PANIC);
+		  ShutDown();
 		}
 	    } while (cbi != *thead);
 	    *thead = 0;
@@ -1391,16 +1401,16 @@ static int lih_r(host, held, hostp)
 
 } /*lih*/
 
+
 /* This could be upgraded to get more space each time */
 /* first pass: find the oldest host which isn't held by anyone */
 /* second pass: find the oldest host who isn't "me" */
 /* always called with hostp unlocked */
-extern struct host *hostList;
 static int GetSomeSpace_r(hostp, locked)
     struct host *hostp;
     int locked;
 {
-    register struct host *hp, *hp1 = (struct host *)0, *hp2 = hostList;
+    register struct host *hp, *hp1 = (struct host *)0;
     int i=0;
 
     cbstuff.GotSomeSpaces++;
@@ -1411,15 +1421,14 @@ static int GetSomeSpace_r(hostp, locked)
     }
     do {
 	lih_host = 0;
-	h_Enumerate_r(lih_r, hp2, (char *)hp1);
+	h_Enumerate_r(lih_r, (char *)hp1);
 	hp = lih_host;
 	if (hp) {
 	    cbstuff.GSS4++;
 	    if ( ! ClearHostCallbacks_r(hp, 0 /* not locked or held */) )
 		return;
-	    hp2 = hp->next;
+	    hp1 = hp;
 	} else {
-	    hp2 = hostList;
 	    hp1 = hostp;
 	    cbstuff.GSS1++;
 	    ViceLog(5,("GSS: Try harder for longest inactive host cnt= %d\n", i));
@@ -1467,8 +1476,9 @@ int ClearHostCallbacks_r(hp, locked)
     struct interfaceAddr interf;
     int code;
     int held = 0;
+    char hoststr[16];
 
-    ViceLog(5,("GSS: Delete longest inactive host %x\n", hp->host));
+    ViceLog(5,("GSS: Delete longest inactive host %s\n", afs_inet_ntoa_r(hp->host,hoststr)));
     if ( !(held = h_Held_r(hp)) )
 	h_Hold_r(hp);
 
@@ -1689,7 +1699,7 @@ main(argc, argv)
     }
     if (err || argc != 1) {
 	fprintf(stderr,
-		"Usage: cbd [-host cbid] [-fid volume vnode] [-stats] [-all] callbackdumpfile\n");
+		"Usage: cbd [-host cbid] [-fid volume vnode] [-stats] callbackdumpfile\n");
 	fprintf(stderr, "[cbid is shown for each host in the hosts.dump file]\n");
 	exit(1);
     }
@@ -1791,11 +1801,12 @@ struct host*		host;
 struct AFSCBFids*	afidp;
 {
 	int i,j;
-	struct rx_connection**	conns;
+	struct rx_connection*	conns[AFS_MAX_INTERFACE_ADDR];
 	struct rx_connection*   connSuccess = 0;
-	afs_int32		*addr;
+	afs_int32			addr[AFS_MAX_INTERFACE_ADDR];
 	static struct rx_securityClass *sc = 0;
 	static struct AFSCBs tc = {0,0};
+	char hoststr[16];
 
 	/* nothing more can be done */
 	if ( !host->interface ) return 1; 	/* failure */
@@ -1810,12 +1821,6 @@ struct AFSCBFids*	afidp;
 	if ( !sc )
 	    sc = (struct rx_securityClass *) rxnull_NewClientSecurityObject();
 
-	i = host->interface->numberOfInterfaces;
-	addr = malloc(i * sizeof(afs_int32));
-	if (!addr) return 1;
-	conns = malloc(i * sizeof(struct rx_connection *));
-	if (!conns) { free(addr); return 1; }
-
 	/* initialize alternate rx connections */
 	for ( i=0,j=0; i < host->interface->numberOfInterfaces; i++)
 	{
@@ -1832,8 +1837,8 @@ struct AFSCBFids*	afidp;
 	}
 
 	assert(j);  /* at least one alternate address */
-	ViceLog(125,("Starting multibreakcall back on all addr for host:%x\n",
-			host->host));
+	ViceLog(125,("Starting multibreakcall back on all addr for host %s\n",
+			afs_inet_ntoa_r(host->host,hoststr)));
 	H_UNLOCK
 	multi_Rx(conns, j)
 	{
@@ -1849,8 +1854,8 @@ struct AFSCBFids*	afidp;
 			connSuccess	     = conns[multi_i];
 			rx_SetConnDeadTime(host->callback_rxcon, 50);
 			rx_SetConnHardDeadTime(host->callback_rxcon, AFS_HARDDEADTIME);
-			ViceLog(125,("multibreakcall success with addr:%x\n",
-					addr[multi_i]));
+			ViceLog(125,("multibreakcall success with addr %s\n",
+					afs_inet_ntoa_r(addr[multi_i],hoststr)));
 			H_UNLOCK
 			multi_Abort; 
 		}
@@ -1862,9 +1867,6 @@ struct AFSCBFids*	afidp;
 		if ( conns[i] != connSuccess )
 			rx_DestroyConnection(conns[i] );
 
-	free(addr);
-	free(conns);
-
 	if ( connSuccess ) return 0;	/* success */
 		else return 1;		/* failure */
 }
@@ -1879,10 +1881,11 @@ MultiProbeAlternateAddress_r(host)
 struct host*		host;
 {
 	int i,j;
-	struct rx_connection**	conns;
+	struct rx_connection*	conns[AFS_MAX_INTERFACE_ADDR];
 	struct rx_connection*   connSuccess = 0;
-	afs_int32		*addr;
+	afs_int32			addr[AFS_MAX_INTERFACE_ADDR];
 	static struct rx_securityClass *sc = 0;
+	char hoststr[16];
 
 	/* nothing more can be done */
 	if ( !host->interface ) return 1; 	/* failure */
@@ -1897,12 +1900,6 @@ struct host*		host;
 	if ( !sc )
 	    sc = (struct rx_securityClass *) rxnull_NewClientSecurityObject();
 
-	i = host->interface->numberOfInterfaces;
-	addr = malloc(i * sizeof(afs_int32));
-	if (!addr) return 1;
-	conns = malloc(i * sizeof(struct rx_connection *));
-	if (!conns) { free(addr); return 1; }
-
 	/* initialize alternate rx connections */
 	for ( i=0,j=0; i < host->interface->numberOfInterfaces; i++)
 	{
@@ -1919,8 +1916,8 @@ struct host*		host;
 	}
 
 	assert(j);  /* at least one alternate address */
-	ViceLog(125,("Starting multiprobe on all addr for host:%x\n",
-			host->host));
+	ViceLog(125,("Starting multiprobe on all addr for host %s\n",
+			afs_inet_ntoa_r(host->host,hoststr)));
 	H_UNLOCK
 	multi_Rx(conns, j)
 	{
@@ -1936,8 +1933,8 @@ struct host*		host;
 			connSuccess	     = conns[multi_i];
 			rx_SetConnDeadTime(host->callback_rxcon, 50);
 			rx_SetConnHardDeadTime(host->callback_rxcon, AFS_HARDDEADTIME);
-			ViceLog(125,("multiprobe success with addr:%x\n",
-					addr[multi_i]));
+			ViceLog(125,("multiprobe success with addr %s\n",
+					afs_inet_ntoa_r(addr[multi_i],hoststr)));
 			H_UNLOCK
 			multi_Abort; 
 		}
@@ -1949,9 +1946,6 @@ struct host*		host;
 		if ( conns[i] != connSuccess )
 			rx_DestroyConnection(conns[i] );
 
-	free(addr);
-	free(conns);
-
 	if ( connSuccess ) return 0;	/* success */
 		else return 1;		/* failure */
 }
