@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.8 2003/01/11 07:42:39 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.18 2002/03/04 16:47:22 shadow Exp $");
 
 #include <ctype.h>
 #ifdef AFS_NT40_ENV
@@ -59,7 +59,7 @@ RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.8 2003/01/11 07:42:39
 #endif
 #endif /* AFS_VFSINCL_ENV */
 #endif	/* AFS_OSF_ENV */
-#include <errno.h>
+#include <sys/errno.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <sys/file.h>
@@ -75,9 +75,6 @@ RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.8 2003/01/11 07:42:39
 #else
 #if	defined(AFS_SUN_ENV)
 #include <sys/vfs.h>
-#ifndef AFS_SUN5_ENV
-#include <mntent.h>
-#endif
 #endif
 #ifdef AFS_SUN5_ENV
 #include <unistd.h>
@@ -116,11 +113,7 @@ RCSID("$Header: /cvs/openafs/src/vol/partition.c,v 1.11.4.8 2003/01/11 07:42:39
 #include "ntops.h"
 #else
 #include "namei_ops.h"
-#if defined(AFS_SGI_ENV)
-#include <sys/dir.h>
-#else
 #include <dirent.h>
-#endif /* AFS_SGI_ENV */
 #endif /* AFS_NT40_ENV */
 #endif /* AFS_NAMEI_ENV */
 #include "vnode.h"
@@ -197,11 +190,9 @@ static void VInitPartition_r(char *path, char *devname, Device dev)
     else
 	DiskPartitionList = dp;
     dp->next = 0;
-    dp->name = (char *)malloc(strlen(path) + 1);
-    strncpy(dp->name, path, strlen(path) + 1);
+    strcpy(dp->name, path);
 #if defined(AFS_NAMEI_ENV) && !defined(AFS_NT40_ENV)
     /* Create a lockfile for the partition, of the form /vicepa/Lock/vicepa */
-    dp->devName = (char *)malloc(2 * strlen(path) + 6);
     strcpy(dp->devName, path);
     strcat(dp->devName, "/");
     strcat(dp->devName, "Lock");
@@ -210,8 +201,7 @@ static void VInitPartition_r(char *path, char *devname, Device dev)
     close(open(dp->devName, O_RDWR | O_CREAT, 0600));
     dp->device = volutil_GetPartitionID(path);
 #else
-    dp->devName = (char *)malloc(strlen(devname) + 1);
-    strncpy(dp->devName, devname, strlen(devname) + 1);
+    strcpy(dp->devName, devname);
     dp->device = dev;
 #endif
     dp->lock_fd = -1;
@@ -811,6 +801,7 @@ void VSetPartitionDiskUsage_r(register struct DiskPartition *dp)
 #else
 void VSetPartitionDiskUsage_r(register struct DiskPartition *dp)
 {
+    extern int errno;
     int fd, totalblks, free, used, availblks, bsize, code;
     int reserved;
 #if AFS_HAVE_STATVFS
@@ -1033,12 +1024,22 @@ void VLockPartition_r(char *name)
     unsigned int	*globalMask;
     int			globalMaskIndex;
 #endif /* defined(AFS_HPUX_ENV) */
+#ifdef AFS_NAMEI_ENV
+#ifdef AFS_AIX42_ENV
+    char LockFileName[MAXPATHLEN + 1];
+
+    sprintf((char *)&LockFileName, "%s/AFSINODE_FSLock", name);
+    partitionName = (char *) &LockFileName;
+#endif
+#endif
     
     if (!dp) return;	/* no partition, will fail later */
     if (dp->lock_fd != -1) return;
 
 #if    defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV)
+#if !defined(AFS_AIX42_ENV) || !defined(AFS_NAMEI_ENV)
     partitionName = dp->devName;
+#endif
     code = O_RDWR;
 #else
     partitionName = dp->name;
@@ -1048,6 +1049,8 @@ void VLockPartition_r(char *name)
     for (retries=25; retries; retries--) {
         dp->lock_fd = open(partitionName, code);
         if (dp->lock_fd != -1) break;
+	if (errno == ENOENT)
+	    code |= O_CREAT;
         pausing.tv_sec = 0;
         pausing.tv_usec = 500000;
         select(0, NULL, NULL, NULL, &pausing);
